===============================
yadi
===============================

.. image:: https://badge.fury.io/py/yadi.png
    :target: http://badge.fury.io/py/yadi
    
.. image:: https://travis-ci.org/saltzm/yadi.png?branch=master
        :target: https://travis-ci.org/saltzm/yadi

.. image:: https://pypip.in/d/yadi/badge.png
        :target: https://crate.io/packages/yadi?version=latest


YADI is a Datalog parsing project for the Advanced Databases course of the DMKM Erasmus Mundus Master's program.

* Free software: BSD license
* Documentation: http://yadi.rtfd.org.
* A description of your project
* Links to the project's ReadTheDocs page
* A TravisCI button showing the state of the build
* "Quickstart" documentation (how to quickly install and use your project)
* A list of non-Python dependencies (if any) and how to install them

Features
--------

* Refer to the project wiki at: https://github.com/saltzm/yadi/wiki 
